#
# spec file for package grass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Notice to maintainer : move this package to real lfhs
%define	shortver 84
%if 0%{?suse_version} >= 1550
BuildRequires:  python3-wxPython
%else
BuildRequires:  python-wxWidgets-devel >= 3.0
%endif

Name:           grass
Version:        8.4.0
Release:        2.6
Summary:        Geographic Resources Analysis Support System
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Other
URL:            https://grass.osgeo.org/
Source:         https://grass.osgeo.org/grass%{shortver}/source/%{name}-%{version}.tar.gz

BuildRequires:  PDAL-devel
BuildRequires:  bison
BuildRequires:  blas-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  flex
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  lapack-devel
BuildRequires:  libXmu-devel
BuildRequires:  libbz2-devel
BuildRequires:  libgdal-devel >= 3
BuildRequires:  libgeos-devel >= 3
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libzstd-devel
BuildRequires:  man
BuildRequires:  mysql-devel
BuildRequires:  ncurses-devel >= 5.5
BuildRequires:  netcdf-devel
BuildRequires:  perl
BuildRequires:  postgresql-devel
BuildRequires:  proj >= 6
BuildRequires:  proj-devel >= 6
BuildRequires:  python3-dateutil
BuildRequires:  python3-devel
BuildRequires:  python3-numpy
BuildRequires:  python3-opengl
BuildRequires:  python3-xml
BuildRequires:  readline-devel
BuildRequires:  sqlite-devel
BuildRequires:  unixODBC-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
# proj contains the required common data files
Requires:       proj >= 6
Requires:       python3-dateutil
Requires:       python3-numpy
Requires:       python3-opengl
Requires:       python3-xml
Requires:       sqlite >= 3
Requires:       unixODBC
Requires:       xterm
Recommends:     grass-doc
Obsoletes:      grass7
%if 0%{?suse_version} >= 1550
Requires:       python3-wxPython
%else
Requires:       python-wxWidgets >= 2.8
%endif

%package doc
Summary:        Documentation for GRASS GIS 7
Group:          Documentation/Other

%package devel
Summary:        Development files for GRASS GIS 7
Group:          Development/Libraries/C and C++
Requires:       grass = %{version}

%description
GRASS (Geographic Resources Analysis Support System), commonly
referred to as GRASS, is a Geographic Information System
(GIS) used for geospatial data management and analysis, image
processing, graphics/maps production, spatial modeling, and
visualization. GRASS is currently used in academic and commercial
settings around the world, as well as by many governmental agencies
and environmental consulting companies.

%description devel
This package contains the development files for GRASS GIS

%description doc
This package contains the HTML documentation files for GRASS GIS

%prep
%setup -q -n grass-%{version}

%define grasver -@GRASS_VERSION_MAJOR@.@GRASS_VERSION_MINOR@.@GRASS_VERSION_RELEASE@
%define grasver2 '-${GRASS_VERSION_MAJOR}.${GRASS_VERSION_MINOR}.${GRASS_VERSION_RELEASE}'

sed -i s/%{grasver}//g include/Make/Platform.make.in
sed -i s/%{grasver}//g grass.pc.in
sed -i s/%{grasver2}//g configure
sed -i s/%{grasver2}//g Makefile
sed -i -e "/GRASS_HEADERS_/ s/@GRASS_HEADERS_GIT_.*@/"$(date -d @${SOURCE_DATE_EPOCH} -u +%FT%T%:z)"/" include/grass/version.h.in
cat include/grass/version.h.in

%define grassprefix %{_libdir}
%define grassdir %{grassprefix}/%{name}%{shortver}
%define grasslib %{grassprefix}/%{name}%{shortver}/lib

# configure with shared libs:
# Pick for upstream travis, normal optflags are not supported
export CFLAGS="-O2 -Werror=implicit-function-declaration"

./configure \
	--prefix=%{grassprefix} \
	--enable-shared \
	--enable-socket \
	--enable-largefile \
	--with-blas \
	--with-bzlib \
	--with-cairo --with-cairo-ldflags=-lfontconfig \
	--with-curses \
	--with-cxx \
	--with-fftw \
	--with-freetype --with-freetype-includes=%{_includedir}/freetype2 \
	--with-gdal=%{_bindir}/gdal-config \
	--with-geos \
	--with-lapack \
	--with-motif \
	--with-mysql --with-mysql-includes=%{_includedir}/mysql \
	--with-netcdf \
	--with-nls \
	--with-odbc \
	--with-opengl \
	--with-openmp \
	--with-pdal \
	--with-png \
	--with-postgres --with-postgres-includes=%{_includedir}/pgsql \
	--with-proj-share=%{_datadir}/proj \
	--with-pthread \
	--with-python \
	--with-readline \
	--with-regex \
	--with-sqlite \
	--with-tiff \
	--with-wxwidgets \
	--with-x \
	--with-zstd

# rpmlint: wrong-script-interpreter /usr/bin/env python3
find . -type f -exec sed -i -e 's:#!%{_bindir}/env python3:#!%{_bindir}/python3:g' {} +

%build
# Make builds reproducible (e.g. "random" colortable example in documentation)
export GRASS_RANDOM_SEED=1234
make prefix=%{grassprefix} PREFIX=%{grassprefix} %{?_smp_mflags}

%install
make prefix=%{buildroot}%{grassprefix} PREFIX=%{buildroot}%{grassprefix} install

# Program sets LD_LIBRARY_PATH pointing to in-source path
# resulting in wrong requires, prevent that
rm -rf dist.*

# don't create a non-standard-directory for a single file
mkdir -p %{buildroot}%{_bindir}
mv %{buildroot}%{grassprefix}/bin/grass %{buildroot}%{_bindir}
rmdir %{buildroot}%{grassprefix}/bin

# changing GISBASE in startup script (deleting %%{buildroot} from path)
sed -i s:%{buildroot}::g %{buildroot}%{_bindir}/grass
sed -i s:%{buildroot}::g %{buildroot}%{grassdir}/include/Make/Grass.make
sed -i s:%{buildroot}::g %{buildroot}%{grassdir}/include/Make/Platform.make
sed -i s:%{buildroot}::g %{buildroot}%{grassdir}%{_sysconfdir}/fontcap

# make grass libraries available on the system
install -d %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo %{grasslib} >> %{buildroot}%{_sysconfdir}/ld.so.conf.d/grass-%{version}.conf

mkdir -p %{buildroot}%{_datadir}/applications
cp  %{buildroot}%{grassdir}/share/applications/grass.desktop %{buildroot}%{_datadir}/applications/grass.desktop
mkdir -p %{buildroot}%{_datadir}/pixmaps
ln -s %{grassdir}/share/icons/hicolor/192x192/apps/grass.png %{buildroot}%{_datadir}/pixmaps/grass.png

rm -rf %{buildroot}%{_libdir}/grass%{shortver}/utils/__pycache__

echo %{grassdir} >%{buildroot}/%{_sysconfdir}/GRASSDIR

%fdupes -s %{buildroot}%{grassdir}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files devel
%{grassdir}/include
%{_sysconfdir}/GRASSDIR

%files doc
%{grassdir}/docs

%files
%config %{_sysconfdir}/ld.so.conf.d/grass-%{version}.conf
%{_bindir}/%{name}
%{grassdir}/bin/*
%{grassdir}%{_sysconfdir}/*
%{grassdir}/gui/*
%{grassdir}/scripts/*
%{grassdir}/share/applications/grass.desktop
%{grassdir}/share/icons/hicolor/*
%{grassdir}/share/metainfo/org.osgeo.grass.appdata.xml
%{_datadir}/applications/grass.desktop
%{_datadir}/pixmaps/grass.png
%lang(ar) %{grassdir}/locale/ar/LC_MESSAGES/*.mo
%lang(bn) %{grassdir}/locale/bn/LC_MESSAGES/*.mo
%lang(cs) %{grassdir}/locale/cs/LC_MESSAGES/*.mo
%lang(de) %{grassdir}/locale/de/LC_MESSAGES/*.mo
%lang(el) %{grassdir}/locale/el/LC_MESSAGES/*.mo
%lang(es) %{grassdir}/locale/es/LC_MESSAGES/*.mo
%lang(fr) %{grassdir}/locale/fr/LC_MESSAGES/*.mo
%lang(fi) %{grassdir}/locale/fi/LC_MESSAGES/*.mo
%lang(hu) %{grassdir}/locale/hu/LC_MESSAGES/*.mo
%lang(id) %{grassdir}/locale/id_ID/LC_MESSAGES/*.mo
%lang(it) %{grassdir}/locale/it/LC_MESSAGES/*.mo
%lang(ja) %{grassdir}/locale/ja/LC_MESSAGES/*.mo
%lang(ko) %{grassdir}/locale/ko/LC_MESSAGES/*.mo
%lang(lv) %{grassdir}/locale/lv/LC_MESSAGES/*.mo
%lang(ml) %{grassdir}/locale/ml/LC_MESSAGES/*.mo
%lang(pl) %{grassdir}/locale/pl/LC_MESSAGES/*.mo
%lang(pt) %{grassdir}/locale/pt/LC_MESSAGES/*.mo
%lang(pt_br) %{grassdir}/locale/pt_BR/LC_MESSAGES/*.mo
%lang(ru) %{grassdir}/locale/ru/LC_MESSAGES/*.mo
%lang(ro) %{grassdir}/locale/ro/LC_MESSAGES/*.mo
%lang(sl) %{grassdir}/locale/sl/LC_MESSAGES/*.mo
%lang(sl) %{grassdir}/locale/si/LC_MESSAGES/*.mo
%lang(ta) %{grassdir}/locale/ta/LC_MESSAGES/*.mo
%lang(th) %{grassdir}/locale/th/LC_MESSAGES/*.mo
%lang(tr) %{grassdir}/locale/tr/LC_MESSAGES/*.mo
%lang(sl) %{grassdir}/locale/uk/LC_MESSAGES/*.mo
%lang(vi) %{grassdir}/locale/vi/LC_MESSAGES/*.mo
%lang(zh) %{grassdir}/locale/zh/LC_MESSAGES/*.mo
%lang(zh_cn) %{grassdir}/locale/zh_CN/LC_MESSAGES/*.mo
%{grassdir}/utils/*.py*
%{grassdir}/utils/g.echo
%{grassdir}/driver/*
%{grassdir}/fonts/*
%{grasslib}/*.so
%{grassdir}/AUTHORS
%{grassdir}/translators.csv
%{grassdir}/translation_status.json
%{grassdir}/contributors*
%{grassdir}/CHANGES
%{grassdir}/COPYING
%{grassdir}/GPL.TXT
%{grassdir}/REQUIREMENTS.md
%{grassdir}/CITING
%{grassdir}/INSTALL.md
%exclude %{grassdir}/demolocation

%changelog
* Mon Nov  4 2024 pgajdos@suse.com
- python3-six is not required
* Tue Aug 20 2024 Enno Tensing <tenno+suse@suij.in>
- Update to 8.4.0, Changelog at https://github.com/OSGeo/grass/releases/tag/8.4.0
* Wed Jul 17 2024 Martin Pluskal <mpluskal@suse.com>
- Drop md5sum of sources as it is pointless
* Fri Jul 12 2024 Enno Tensing <tenno+suse@suij.in>
- Update 8.3.2, Changelog at https://github.com/OSGeo/grass/releases/tag/8.3.2
* Thu Mar  2 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 8.2.1:
  * more than 80 improvements and fixes
  * Full changleog at https://github.com/OSGeo/grass/releases/tag/8.2.1
- Changes in previous releases:
  * 8.2: https://trac.osgeo.org/grass/wiki/Grass8/NewFeatures82
  * 8.0: https://trac.osgeo.org/grass/wiki/Grass8/NewFeatures80
* Wed Dec  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make build reproducible:
  * Set GRASS_RANDOM_SEED for "random" colortable in documentation.
  * Use SOURCE_DATE_EPOCH for version instead of current date.
- Remove direct dependency on wxWidgets, dependency on Python
  bindings is sufficient.
- Drop some more extraneous build dependencies.
* Fri Nov 25 2022 Predrag Ivanović <predivan@mts.rs>
- Update to 7.8.7:
  * More than 40 fixes and improvements with respect to the release 7.8.6.
  Changelog at https://github.com/OSGeo/grass/releases/tag/7.8.7
* Sun Oct 10 2021 Predrag Ivanović <predivan@mts.rs>
- Update to 7.8.6:
  * Over 145 fixes and improvements with respect to 7.8.5
  Changelog at https://trac.osgeo.org/grass/wiki/Release/7.8.6-News
  * Drop b86314c7.patch, merged upstream.
* Wed Jun 16 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Add upstream patch b86314c7.patch to fix build failure due
  to gdal 3.3.0. This close boo#1187371 and upstream issue#1649
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 7.8.5:
  * over 80 fixes and improvements
  * see https://trac.osgeo.org/grass/wiki/Release/7.8.5-News#Overviewofchanges
* Sun Oct 11 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 7.8.4
  see https://trac.osgeo.org/grass/wiki/Release/7.8.4-News
  Fixes to support wxPython 4.1x
* Tue May 19 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 7.8.3:
  * G78:i.vi: write out FCELL instead of DCELL
  * G78:r.kappa: maps[0] is the reference and maps[1] is the classified map
  * grass7 startup: added --config date parameter
  * Various fixes, details at https://trac.osgeo.org/grass/wiki/Release/7.8.3-News
- Drop %%{grassdir}/config.status as it is not installed anymore
* Tue Apr 28 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 7.8.2:
  * important PROJ 4/5/6 related datum handling fixes
  * wxGUI fixes
  * fix for the vector import from PostGIS databases
* Tue Apr 28 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use python3-wxPython on Tumbleweed since python-wxWidgets has
  been dropped (was python2 only)
* Mon Dec  2 2019 Dirk Stoecker <opensuse@dstoecker.de>
- Allow autoconfig of grass directory in software using grass
* Sat Nov 30 2019 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.8.1:
  * The GRASS GIS 7.8.1 release provides more than 80 fixes and improvements with respect to the stable release 7.8.0.
  * The most important change is the new Python-3 support.
  * In this release, PROJ 6 and GDAL 3 support has been added.
  * The new version is backward compatible with older GRASS 7.x releases and older GDAL 2.x and PROJ 4/5 releases.
  * More details: https://trac.osgeo.org/grass/wiki/Release/7.8.1-News
- Use Python 3.
* Wed Jul 10 2019 Dirk Stoecker <opensuse@dstoecker.de>
- remove non-standard bin directory
* Tue Jul  9 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Change prefix to /usr.
* Sat Jul  6 2019 Jan Engelhardt <jengelh@inai.de>
- Rename grass-docs to grass-doc to look more like the rest
  of openSUSE packages.
- Remove unnecessary Requires of the documentation. Reading HTML
  requires a browser at best, but not grass.
- Avoid name repetition in summary.
- Place files somewhere within /usr, not /opt.
* Thu Apr  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 7.6.1 version which support natively proj6
  notice that upstream now decide to install in grass76 directory
  proj version 6 is now forced everywhere
- Packaging fix related path to use %%{name}%%{shortver}
  add bzip2 support
  + Remove old %%if suse_version long time obsolete
  + Update date and use https for URL
* Thu Mar 21 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use proj5, as proj is now at version 6 and is not compatible yet
* Tue Dec 18 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Make symlinks in /usr/bin/: fix desktop files and avoid to
  update PATH
* Thu Dec 13 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 7.4.3:
  * hotfix release for only two issues discovered in the previous
    stable version 7.4.2
- Update to 7.4.2:
  * more than 50 stability fixes and improvements compared to
    the previous stable version 7.4.1
* Wed Jul 25 2018 ecsos@opensuse.org
- fix build error for Leap 42.3 and 15.0
* Wed Jul 18 2018 guillaume.gardet@opensuse.org
- Update to 7.4.1
- Removed upstreamed patch:
  * upstream-issue-3331-floats2.patch
* Wed Jul 18 2018 guillaume.gardet@opensuse.org
- Enable openmp and pthreads
* Thu Mar  8 2018 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.4.0 final
  After a bit more than one year of development the new update release
  GRASS GIS 7.4.0 is available.
  It provides more than 480 stability fixes and improvements
  compared to the previous stable version 7.2.
  An overview of the new features in the 7.4 release series
  is available at
  https://trac.osgeo.org/grass/wiki/Grass7/NewFeatures74
  https://trac.osgeo.org/grass/wiki/Release/7.4.0-News
* Fri Oct 13 2017 bruno@ioda-net.ch
- update to 7.2.2 bugfix release
  A series of stability fixes, manual improvements and a few
  language translations have been added.
  The GRASS GIS 7.2.2 release provides more than 120 fixes and
  improvements with respect to GRASS GIS 7.2.1
  see details on
  https://trac.osgeo.org/grass/wiki/Release/7.2.2-News
* Fri Oct 13 2017 ecsos@opensuse.org
- fix build error for Tumbleweed
* Wed Jun 21 2017 bruno@ioda-net.ch
- Use correct fix for upstream issue#3331 to fix gcc7 build
  Add upstream-issue-3331-floats2.patch
  Remove ctypesgencore_preprocessor_fix.patch
* Fri Jun  9 2017 bruno@ioda-net.ch
- Update to 7.2.1 bugfixes release
- Removed upstream merged patch hicolor-icons.patch
- Added ctypesgencore_preprocessor_fix.patch to fix build issue
  with gcc7 https://trac.osgeo.org/grass/ticket/3331
* Sun Feb 26 2017 bruno@ioda-net.ch
- Packaging :
  + Use unmodified upstream tar.gz + md5sum
  + Adjust year copyright
  + Use spdx licence format GPL-2.0+
* Sat Feb 25 2017 bruno@ioda-net.ch
- Adapt wxWidget by openSUSE version : fixes for Tumbleweed and
  SLE builds
* Wed Dec 28 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.2.0 final
* Mon Oct  3 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.5
* Tue Jul  5 2016 toddrme2178@gmail.com
- Fix Group tag.
* Sat May 14 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Enabled build against Lapack and BLAS
* Tue May 10 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Remove %%{buildroot} from make files (#976959)
* Tue May 10 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.4 final
* Tue Mar  1 2016 fisiu@opensuse.org
- Don't require libgdal1 explicit.
* Thu Jan 28 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.3 final
* Fri Nov 20 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.2 final
* Sun Sep 13 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Spec cleanup provided by Markus Neteler
* Sat Aug  1 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.1 final
* Thu Feb 26 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- libgeos fix
* Fri Feb 20 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.0 final
* Sun Feb  8 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.0RC2
* Sat Feb  7 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- removed swig dependency, not used in grass7
* Sat Jan 24 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- spec file cleanup
* Wed Jan 14 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 7.0.0RC1
* Mon Dec 22 2014 dassau@gbd-consult.de
- build beta4
* Thu Aug  7 2014 dassau@gbd-consult.de
- build beta3
* Fri Mar 28 2014 Angelos Tzotsos <tzotsos@opensuse.org>
- build beta2
* Fri Mar 28 2014 dassau@gbd-consult.de
- build beta1
* Mon Feb 24 2014 dassau@gbd-consult.de
- update version from trunk
* Thu Jan  2 2014 dassau@gbd-consult.de
- update version from trunk
* Thu Dec 19 2013 dassau@gbd-consult.de
- update version from trunk
* Mon Nov  4 2013 dassau@gbd-consult.de
- update version from trunk
* Tue Oct 15 2013 dassau@gbd-consult.de
- update version from trunk
* Fri Oct  4 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- update version from trunk
* Sun Sep 29 2013 dassau@gbd-consult.de
- update version from trunk
* Tue Sep 24 2013 dassau@gbd-consult.de
- update version from trunk
* Mon Sep 16 2013 dassau@gbd-consult.de
- update version from trunk
* Sun Sep  8 2013 dassau@gbd-consult.de
- update version from trunk
* Fri Aug 30 2013 dassau@gbd-consult.de
- update version from trunk
* Sun Aug 25 2013 dassau@gbd-consult.de
- update version from trunk
* Mon Aug 19 2013 dassau@gbd-consult.de
- update version from trunk
* Sat Aug 10 2013 dassau@gbd-consult.de
- update version from trunk
* Sat Aug  3 2013 dassau@gbd-consult.de
- update version from trunk
* Sun Jul 28 2013 dassau@gbd-consult.de
- update version from trunk
* Sat Jul 20 2013 dassau@gbd-consult.de
- update version from trunk
* Wed Jul 10 2013 dassau@gbd-consult.de
- update version from trunk
* Tue Jul  2 2013 dassau@gbd-consult.de
- update version from trunk
* Mon Jun 24 2013 dassau@gbd-consult.de
- update version from trunk
* Tue Jun 11 2013 dassau@gbd-consult.de
- update version from trunk
* Thu Feb 14 2013 dassau@gbd-consult.de
- update version from trunk
* Fri Oct  5 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- update version from trunk
- Added libXmu-devel dependency
* Wed Apr 18 2012 dassau@gbd-consult.de
- update version from trunk
* Wed Feb 22 2012 dassau@gbd-consult.de
- added python-dateutil dependency for temporal GIS modules
* Mon Jan 16 2012 dassau@gbd-consult.de
- update version from trunk
* Wed Dec  7 2011 otto.dassau@gmx.de
- update version from trunk
* Mon Oct 10 2011 otto.dassau@gmx.de
- update version from trunk
* Wed Aug 17 2011 idonmez@novell.com
- Fix proj dependency
* Wed Aug 17 2011 dassau@gbd-consult.de
- update version from trunk
- added .changes file
* Wed Mar  9 2011 dassau@gbd-consult.de
- package GRASS7 development packages for testing
